Learn R Programming

PhyActBedRest (version 1.0)

wa_tp5788: Waist Accelerometer data subject sj6909

Description

This data set gives counts/minute for subject sj6909, "Axis 1". The first two columns are date and time information.

Usage

tp5788_wa

Arguments

Format

A matix 3 x 3319

Collected at the Energy Balance Laboratory at Vanderbilt University Medical Center (data owner), using a Actigraph GT1M accelerometer.