Learn R Programming

PhyActBedRest (version 1.0)

wr_tp5788_cc: Waist Accelerometer data subject sj6909

Description

This data set gives counts/minute for subject sj6909, "Axis 1". The first two columns are date and time information, but labeled "calender" and clock".

Usage

wr_tp5788_cc

Arguments

Format

A matix 3 x 2092

Collected at the Energy Balance Laboratory at Vanderbilt University Medical Center (data owner), using a Actigraph GT1M accelerometer.